@@ -10,10 +10,16 @@ class AutocompleteChangelistFiltersAdminMixin:
         return changelist_view
 
     def _update_changelist_media(
-        self, changelist_view: TemplateResponse
+        self,
+        changelist_view: TemplateResponse,
     ) -> None:
-        if "cl" not in changelist_view.context_data:
+        try:
+            context_data = changelist_view.context_data
+        except AttributeError:
             return
+        else:
+            if "cl" not in context_data:
+                return
 
         for filter_spec in changelist_view.context_data["cl"].filter_specs:
             if not getattr(filter_spec, "media", None):
